@@ -1,7 +1,7 @@
 import os
 import tensorflow as tf
 import tensorflow_hub as hub
-from imgFnc import load_image, show_images
+from tfhub_styletransfer_wrapper.imgFnc import load_image, show_images
 
 
 def evaluate_hub(content_image_filename, style_image_filename, output_size, style_size, plot_onoff=False):
